@@ -9,4 +9,8 @@ _config_dir = os.path.join(PROJECT_ROOT ,'config')
 TEMPLATES_DIR = os.path.join(_config_dir ,'templates')
 GENERATED_DIR = os.path.join(_config_dir ,'generated')
 
-HOST = Site.objects.get_current().domain.split(':')[0]
+#Error is thrown when running "./manage.py syncdb" for the first time and this app is installed.
+try:
+	HOST = Site.objects.get_current().domain.split(':')[0]
+except:
+	HOST = 'localhost'
